<?php
/**
 * @file
 * group_mind_gamification.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function group_mind_gamification_default_rules_configuration() {
  $items = array();

  $items['rules_add_a_question'] = entity_import('rules_config', '{ "rules_add_a_question" : {
        "LABEL" : "Add a question",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "group_mind_gamification" ],
        "ON" : { "node_insert--answers_question" : { "bundle" : "answers_question" } },
        "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "node:author" ],
              "points" : "'. GAMIFICATION_CREATE_QUESTION_POINTS .'",
              "tid" : "0",
              "entity" : [ "node" ],
              "description" : "'. t('Creation of a question') .'",
              "operation" : "Create question",
              "display" : 1,
              "moderate" : "approved"
            }
          },
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "node:author" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You add the question \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E. "
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } },
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_created_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_created_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_created_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_created_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "100",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_100th_created_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "250",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_250th_created_question"
            }
          }
        ]
      }
    }'
  );

  $items['rules_delete_a_question'] = entity_import('rules_config', '{ "rules_delete_a_question" : {
    "LABEL" : "Delete a question",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--answers_question" : { "bundle" : "answers_question" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_QUESTION_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of a question'). '",
          "operation" : "Delete question",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Question \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_add_an_answer'] = entity_import('rules_config', '{ "rules_add_an_answer" : {
    "LABEL" : "Add an answer",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "rules", "userpoints_rules" ],
    "ON" : {
      "node_insert--answers_answer" : { "bundle" : "answers_answer" }
    },
    "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. GAMIFICATION_CREATE_ANSWER_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Creation of an answer') .'",
          "operation" : "Create answer",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You add the answer \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E. "
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_delete_an_answer'] = entity_import('rules_config', '{ "rules_delete_an_answer" : {
    "LABEL" : "Delete an answer",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--answers_answer" : { "bundle" : "answers_answer" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_ANSWER_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of an answer') .'",
          "operation" : "Delete answer",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Answer \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_add_an_idea'] = entity_import('rules_config', '{ "rules_add_an_idea" : {
        "LABEL" : "Add an Idea",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "group_mind_gamification" ],
        "ON" : { "node_insert--idea" : { "bundle" : "idea" } },
        "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "node:author" ],
              "points" : "'. GAMIFICATION_CREATE_IDEA_POINTS .'",
              "tid" : "0",
              "entity" : [ "node" ],
              "description" : "'. t('Creation of an Idea') .'",
              "operation" : "Create Idea",
              "display" : 1,
              "moderate" : "approved"
            }
          },
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "node:author" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You created the Idea \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } },
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_created_idea"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_created_idea"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_created_idea"
            }
          }
        ]
      }
    }'
  );

  $items['rules_delete_an_idea'] = entity_import('rules_config', '{ "rules_delete_an_idea" : {
    "LABEL" : "Delete an idea",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--idea" : { "bundle" : "idea" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_IDEA_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of an idea') .'",
          "operation" : "Delete idea",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Idea \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_add_a_project'] = entity_import('rules_config', '{ "rules_add_a_project" : {
        "LABEL" : "Add a project",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "group_mind_gamification" ],
        "ON" : { "node_insert--project" : { "bundle" : "project" } },
        "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
        "DO" : [
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "node:author" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You created the Project \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } },
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_created_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_created_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_created_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_created_project"
            }
          }
        ]
      }
    }'
  );

  $items['rules_delete_a_project'] = entity_import('rules_config', '{ "rules_delete_a_project" : {
    "LABEL" : "Delete a project",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--project" : { "bundle" : "project" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_PROJECT_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of a project') .'",
          "operation" : "Delete project",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Project \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_add_a_release'] = entity_import('rules_config', '{ "rules_add_a_release" : {
    "LABEL" : "Add a release",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "rules", "userpoints_rules" ],
    "ON" : {
      "node_insert--project_release" : { "bundle" : "project_release" }
    },
    "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. GAMIFICATION_CREATE_RELEASE_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Creation of a release') .'",
          "operation" : "Create release",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You created the Release \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
  }');

  $items['rules_delete_a_release'] = entity_import('rules_config', '{ "rules_delete_a_release" : {
    "LABEL" : "Delete a release",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--project_release" : { "bundle" : "project_release" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_RELEASE_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of a release'). '",
          "operation" : "Delete release",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Release \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_add_an_article'] = entity_import('rules_config', '{ "rules_add_an_article" : {
        "LABEL" : "Add an article",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "group_mind_gamification" ],
        "ON" : { "node_insert--blog_article" : { "bundle" : "blog_article" } },
        "IF" : [ { "data_is" : { "data" : [ "node:status" ], "value" : "1" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "node:author" ],
              "points" : "'. GAMIFICATION_CREATE_ARTICLE_POINTS .'",
              "tid" : "0",
              "entity" : [ "node" ],
              "description" : "'. t('Creation of an article') .'",
              "operation" : "Create article",
              "display" : 1,
              "moderate" : "approved"
            }
          },
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "node:author" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You created the Article \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } },
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_created_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_created_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_created_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_created_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "node:author" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_blogger"
            }
          }
        ]
      }
    }'
  );

  $items['rules_delete_an_article'] = entity_import('rules_config', '{ "rules_delete_an_article" : {
    "LABEL" : "Delete an article",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "userpoints_rules", "rules" ],
    "ON" : { "node_delete--blog_article" : { "bundle" : "blog_article" } },
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_CREATE_ARTICLE_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "description" : "'. t('Deletion of an article') .'",
          "operation" : "Delete article",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "node:author" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "Article \u0022[node:title]\u0022 deleted"
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_voteup_idea'] = entity_import('rules_config', '{ "rules_voteup_idea" : {
    "LABEL" : "voteup_idea",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "voting_rules", "userpoints_rules", "rules" ],
    "ON" : { "voting_rules_insert_node" : [] },
    "IF" : [
      { "node_is_of_type" : { "node" : [ "node" ], "type" : { "value" : { "idea" : "idea" } } } },
      { "voting_rules_condition_check_vote_value" : { "vote" : [ "vote" ], "value" : "1" } }
    ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. GAMIFICATION_VOTEUP_IDEA_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Upvote an Idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "vote:user" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You up voted the Idea \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
  }');

  $items['rules_votedown_idea'] = entity_import('rules_config', '{ "rules_votedown_idea" : {
    "LABEL" : "votedown_idea",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "voting_rules", "userpoints_rules", "rules" ],
    "ON" : { "voting_rules_insert_node" : [] },
    "IF" : [
      { "node_is_of_type" : { "node" : [ "node" ], "type" : { "value" : { "idea" : "idea" } } } },
      { "voting_rules_condition_check_vote_value" : { "vote" : [ "vote" ], "value" : "-1" } }
    ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. GAMIFICATION_VOTEDOWN_IDEA_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Downvote of your idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
      },
  	  { "userpoints_action_grant_points" : {
          "user" : [ "vote:user" ],
          "points" : "'. GAMIFICATION_VOTEDOWN_IDEA_VOTER_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Downvote an idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
  	  },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "vote:user" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You down voted the Idea \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
  }');

  $items['rules_voteup_idea_cancel'] = entity_import('rules_config', '{ "rules_voteup_idea_cancel" : {
    "LABEL" : "voteup_idea_cancel",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "voting_rules", "userpoints_rules", "rules" ],
    "ON" : { "voting_rules_delete_node" : [] },
    "IF" : [
      { "node_is_of_type" : { "node" : [ "node" ], "type" : { "value" : { "idea" : "idea" } } } },
      { "voting_rules_condition_check_vote_value" : { "vote" : [ "vote" ], "value" : "1" } }
    ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_VOTEUP_IDEA_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Cancel upvote on idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "vote:user" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You cancelled your up vote on the Idea \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_votedown_idea_cancel'] = entity_import('rules_config', '{ "rules_votedown_idea_cancel" : {
    "LABEL" : "votedown_idea_cancel",
    "PLUGIN" : "reaction rule",
    "OWNER" : "rules",
    "TAGS" : [ "gamification" ],
    "REQUIRES" : [ "voting_rules", "userpoints_rules", "rules" ],
    "ON" : { "voting_rules_delete_node" : [] },
    "IF" : [
      { "node_is_of_type" : { "node" : [ "node" ], "type" : { "value" : { "idea" : "idea" } } } },
      { "voting_rules_condition_check_vote_value" : { "vote" : [ "vote" ], "value" : "-1" } }
    ],
    "DO" : [
      { "userpoints_action_grant_points" : {
          "user" : [ "vote:user" ],
          "points" : "'. - (int) GAMIFICATION_VOTEDOWN_IDEA_VOTER_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Cancel downvote idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "userpoints_action_grant_points" : {
          "user" : [ "node:author" ],
          "points" : "'. - (int) GAMIFICATION_VOTEDOWN_IDEA_POINTS .'",
          "tid" : "0",
          "entity" : [ "node" ],
          "operation" : "'. t('Cancel downvote your idea') .'",
          "display" : 1,
          "moderate" : "approved"
        }
      },
      { "entity_create" : {
          "USING" : {
            "type" : "message",
            "param_type" : "activity_stream",
            "param_user" : [ "vote:user" ]
          },
          "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
        }
      },
      { "data_set" : {
          "data" : [ "activity-stream:field-activity-stream-body:value" ],
          "value" : "You canceled your down vote on the Idea \u003Ca href=\u0022[node:url]\u0022\u003E[node:title]\u003C\/a\u003E."
        }
      },
      { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
    ]
  }
}');

  $items['rules_view_question'] = entity_import('rules_config', '{ "rules_view_question" : {
        "LABEL" : "View question",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "group_mind_gamification" ],
        "ON" : { "node_view--answers_question" : { "bundle" : "answers_question" } },
        "IF" : [
          { "NOT user_has_role" : {
              "account" : [ "site:current-user" ],
              "roles" : { "value" : { "1" : "1" } }
            }
          },
          { "data_is" : { "data" : [ "view-mode" ], "value" : "full" } }
        ],
        "DO" : [
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_viewed_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_viewed_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_viewed_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "100",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_100_viewed_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "250",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_250_viewed_question"
            }
          },
          { "log_gamification_events" : {
              "count" : "500",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_500_viewed_question"
            }
          }
        ]
      }
    }'
  );

  $items['rules_view_project'] = entity_import('rules_config', '{ "rules_view_project" : {
        "LABEL" : "View project",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "group_mind_gamification" ],
        "ON" : { "node_view--project" : { "bundle" : "project" } },
        "IF" : [
          { "NOT user_has_role" : {
              "account" : [ "site:current-user" ],
              "roles" : { "value" : { "1" : "1" } }
            }
          },
          { "data_is" : { "data" : [ "view-mode" ], "value" : "full" } }
        ],
        "DO" : [
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_viewed_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_viewed_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_viewed_project"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_viewed_project"
            }
          }
        ]
      }
    }'
  );
  $items['rules_view_idea'] = entity_import('rules_config', '{ "rules_view_idea" : {
        "LABEL" : "View idea",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "group_mind_gamification" ],
        "ON" : { "node_view--idea" : { "bundle" : "idea" } },
        "IF" : [
          { "NOT user_has_role" : {
              "account" : [ "site:current-user" ],
              "roles" : { "value" : { "1" : "1" } }
            }
          },
          { "data_is" : { "data" : [ "view-mode" ], "value" : "full" } }
        ],
        "DO" : [
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_viewed_idea"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_viewed_idea"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_viewed_idea"
            }
          }
        ]
      }
    }'
  );

  $items['rules_view_article'] = entity_import('rules_config', '{ "rules_view_article" : {
        "LABEL" : "View article",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "gamification" ],
        "REQUIRES" : [ "rules", "group_mind_gamification" ],
        "ON" : { "node_view--blog_article" : { "bundle" : "blog_article" } },
        "IF" : [
          { "NOT user_has_role" : {
              "account" : [ "site:current-user" ],
              "roles" : { "value" : { "1" : "1" } }
            }
          },
          { "data_is" : { "data" : [ "view-mode" ], "value" : "full" } }
        ],
        "DO" : [
          { "log_gamification_events" : {
              "count" : "1",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_1st_viewed_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "5",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_5th_viewed_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "25",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_25th_viewed_article"
            }
          },
          { "log_gamification_events" : {
              "count" : "50",
              "user" : [ "site:current-user" ],
              "entity" : [ "node" ],
              "action_set" : "rules_attribute_badge_for_50th_viewed_article"
            }
          }
        ]
      }
    }'
  );

  $items['rules_log_badge_attribution'] = entity_import('rules_config', '{ "rules_log_badge_attribution" : {
        "LABEL" : "Log badge attribution",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "rules", "user_badges" ],
        "ON" : { "user_badges_badge_given" : [] },
        "DO" : [
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "user" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You were given the \u0027[badge-name:value]\u0027 badge !"
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } },
          { "drupal_message" : { "message" : "You earned the badge \u0022[badge-name:value]\u0022 !" } }
        ]
      }
    }'
  );

  $items['rules_view_guidelines'] = entity_import('rules_config', '{ "rules_view_guidelines" : {
        "LABEL" : "View Guidelines",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "rules" ],
        "ON" : { "node_view" : [] },
        "IF" : [
          { "data_is" : { "data" : [ "node:nid" ], "value" : "'. GAMIFICATION_GUIDELINES_NID .'" } },
          { "NOT user_has_role" : {
              "account" : [ "site:current-user" ],
              "roles" : { "value" : { "1" : "1" } }
            }
          },
          { "data_is" : { "data" : [ "view-mode" ], "value" : "full" } },
          { "NOT user_badges_has_badge" : { "badge_id" : "46", "user" : [ "site:current-user" ] } }
        ],
        "DO" : [
            { "component_rules_attribute_badge_guidelines" : { "attribute_badge_guidelines_user" : [ "site:current-user" ] } }
        ]
      }
    }'
  );

  $items['rules_best_member_of_the_month_badge_given'] = entity_import('rules_config', '{ "rules_best_member_of_the_month_badge_given" : {
        "LABEL" : "Best member of the month badge given",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "user_badges" ],
        "ON" : { "user_badges_badge_given" : [] },
        "IF" : [ { "data_is" : { "data" : [ "badge-id" ], "value" : "'. GAMIFICATION_BEST_MEMBER_OF_MONTH_BADGE .'" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "user" ],
              "points" : "'. GAMIFICATION_BEST_MEMBER_OF_MONTH_POINTS .'",
              "tid" : "0",
              "entity" : [ "" ],
              "description" : "Best member of the month",
              "operation" : "Best member of the month",
              "display" : 1,
              "moderate" : "approved"
            }
          }
        ]
      }
    }'
  );

  $items['rules_best_member_of_the_quarter_badge_given'] = entity_import('rules_config', '{ "rules_best_member_of_the_quarter_badge_given" : {
        "LABEL" : "Best member of the quarter badge given",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "user_badges" ],
        "ON" : { "user_badges_badge_given" : [] },
        "IF" : [ { "data_is" : { "data" : [ "badge-id" ], "value" : "'. GAMIFICATION_BEST_MEMBER_OF_QUARTER_BADGE .'" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "user" ],
              "points" : "'. GAMIFICATION_BEST_MEMBER_OF_QUARTER_POINTS .'",
              "tid" : "0",
              "entity" : [ "" ],
              "description" : "Best member of the quarter",
              "operation" : "Best member of the quarter",
              "display" : 1,
              "moderate" : "approved"
            }
          }
        ]
      }
    }'
  );

  $items['rules_best_member_of_the_year_badge_given'] = entity_import('rules_config', '{ "rules_best_member_of_the_year_badge_given" : {
        "LABEL" : "Best member of the year badge given",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "rules", "userpoints_rules", "user_badges" ],
        "ON" : { "user_badges_badge_given" : [] },
        "IF" : [ { "data_is" : { "data" : [ "badge-id" ], "value" : "'. GAMIFICATION_BEST_MEMBER_OF_YEAR_BADGE .'" } } ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "user" ],
              "points" : "'. GAMIFICATION_BEST_MEMBER_OF_YEAR_POINTS .'",
              "tid" : "0",
              "entity" : [ "" ],
              "description" : "Best member of the year",
              "operation" : "Best member of the year",
              "display" : 1,
              "moderate" : "approved"
            }
          }
        ]
      }
    }'
  );

  $items['rules_add_first_release_on_a_project'] = entity_import('rules_config', '{ "rules_add_first_release_on_a_project" : {
        "LABEL" : "Add first release on a project",
        "PLUGIN" : "reaction rule",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "group_mind_gamification", "userpoints_rules", "rules" ],
        "ON" : { "node_insert--project_release" : { "bundle" : "project_release" } },
        "IF" : [
          { "rules_condition_first_project_release" : { "release" : [ "node" ] } }
        ],
        "DO" : [
          { "userpoints_action_grant_points" : {
              "user" : [ "node:author" ],
              "points" : "'. GAMIFICATION_CREATE_PROJECT_POINTS .'",
              "tid" : "0",
              "entity" : [ "node" ],
              "description" : "First release on a project",
              "operation" : "First release on a project",
              "display" : 1,
              "moderate" : "approved"
            }
          }
        ]
      }
    }'
  );

  // Import components
  $items += _group_mind_gamification_rules_default_components();

  return $items;
}

/**
 * Implements hook_default_rules_configuration_alter().
 */
function group_mind_gamification_default_rules_configuration_alter(&$configs) {
  // Question rules
  if (array_key_exists('rules_voteup_question', $configs)) {
    $rule = $configs['rules_voteup_question'];
    _group_mind_gamification_alter_voteup_question_rule($rule);
  }

  if (array_key_exists('rules_votedown_question', $configs)) {
    $rule = $configs['rules_votedown_question'];
    _group_mind_gamification_alter_votedown_question_rule($rule);
  }

  if (array_key_exists('rules_voteup_question_cancel', $configs)) {
    $rule = $configs['rules_voteup_question_cancel'];
    _group_mind_gamification_alter_voteup_question_cancel_rule($rule);
  }

  if (array_key_exists('rules_votedown_question_cancel', $configs)) {
    $rule = $configs['rules_votedown_question_cancel'];
    _group_mind_gamification_alter_votedown_question_cancel_rule($rule);
  }

  // Answer rules
  if (array_key_exists('rules_voteup_answer', $configs)) {
    $rule = $configs['rules_voteup_answer'];
    _group_mind_gamification_alter_voteup_answer_rule($rule);
  }

  if (array_key_exists('rules_votedown_answer', $configs)) {
    $rule = $configs['rules_votedown_answer'];
    _group_mind_gamification_alter_votedown_answer_rule($rule);
  }

  if (array_key_exists('rules_voteup_answer_cancel', $configs)) {
    $rule = $configs['rules_voteup_answer_cancel'];
    _group_mind_gamification_alter_voteup_answer_cancel_rule($rule);
  }

  if (array_key_exists('rules_votedown_answer_cancel', $configs)) {
    $rule = $configs['rules_votedown_answer_cancel'];
    _group_mind_gamification_alter_votedown_answer_cancel_rule($rule);
  }

  if (array_key_exists('rules_flag_answers_best_answer', $configs)) {
    $rule = $configs['rules_flag_answers_best_answer'];
    _group_mind_gamification_alter_flag_best_answer_rule($rule);
  }

  if (array_key_exists('rules_unflag_answers_best_answer', $configs)) {
    $rule = $configs['rules_unflag_answers_best_answer'];
    _group_mind_gamification_alter_unflag_best_answer_rule($rule);
  }

  if (array_key_exists('answers_userpoints_flag_answers_own_best_answer', $configs)) {
    $rule = $configs['answers_userpoints_flag_answers_own_best_answer'];
    _group_mind_gamification_alter_flag_best_own_answer_rule($rule);
  }

  if (array_key_exists('answers_userpoints_unflag_answers_own_best_answer', $configs)) {
    $rule = $configs['answers_userpoints_unflag_answers_own_best_answer'];
    _group_mind_gamification_alter_unflag_best_own_answer_rule($rule);
  }
}

/**
 * Return the default rules components
 */
function _group_mind_gamification_rules_default_components() {
  $components = array();

  $components['rules_attribute_badge_for_1st_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_created_question" : {
        "LABEL" : "Attribute badge for 1st created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "3",
              "user" : [ "attribute-badge-for-1st-created-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_created_question" : {
        "LABEL" : "Attribute badge for 5th created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "4",
              "user" : [ "attribute-badge-for-5th-created-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_created_question" : {
        "LABEL" : "Attribute badge for 25th created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "5",
              "user" : [ "attribute-badge-for-25th-created-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_created_question" : {
        "LABEL" : "Attribute badge for 50th created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "6",
              "user" : [ "attribute-badge-for-50th-created-question-user" ]
            }
          }
        ]
      }
    }
  ');

  $components['rules_attribute_badge_for_100th_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_100th_created_question" : {
        "LABEL" : "Attribute badge for 100th created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_100th_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "7",
              "user" : [ "attribute-badge-for-100th-created-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_250th_created_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_250th_created_question" : {
        "LABEL" : "Attribute badge for 250th created question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_250th_created_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "8",
              "user" : [ "attribute-badge-for-250th-created-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_created_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_created_project" : {
        "LABEL" : "Attribute badge for 1st created project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_created_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "9",
              "user" : [ "attribute-badge-for-1st-created-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_created_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_created_project" : {
        "LABEL" : "Attribute badge for 5th created project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_created_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "10",
              "user" : [ "attribute-badge-for-5th-created-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_created_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_created_project" : {
        "LABEL" : "Attribute badge for 25th created project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_created_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "11",
              "user" : [ "attribute-badge-for-25th-created-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_created_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_created_project" : {
        "LABEL" : "Attribute badge for 50th created project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_created_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "12",
              "user" : [ "attribute-badge-for-50th-created-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_created_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_created_idea" : {
        "LABEL" : "Attribute badge for 1st created idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_created_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "13",
              "user" : [ "attribute-badge-for-1st-created-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_created_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_created_idea" : {
        "LABEL" : "Attribute badge for 5th created idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_created_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "14",
              "user" : [ "attribute-badge-for-5th-created-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_created_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_created_idea" : {
        "LABEL" : "Attribute badge for 25th created idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_created_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "15",
              "user" : [ "attribute-badge-for-25th-created-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_created_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_created_article" : {
        "LABEL" : "Attribute badge for 1st created article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_created_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "16",
              "user" : [ "attribute-badge-for-1st-created-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_created_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_created_article" : {
        "LABEL" : "Attribute badge for 5th created article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_created_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "17",
              "user" : [ "attribute-badge-for-5th-created-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_created_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_created_article" : {
        "LABEL" : "Attribute badge for 25th created article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_created_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "18",
              "user" : [ "attribute-badge-for-25th-created-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_created_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_created_article" : {
        "LABEL" : "Attribute badge for 50th created article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_created_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "19",
              "user" : [ "attribute-badge-for-50th-created-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_viewed_question" : {
        "LABEL" : "Attribute badge for 5th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-5th-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_viewed_question" : {
        "LABEL" : "Attribute badge for 25th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "21",
              "user" : [ "attribute-badge-for-25th-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-25th-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_viewed_question" : {
        "LABEL" : "Attribute badge for 50th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "22",
              "user" : [ "attribute-badge-for-50th-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-50th-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "21",
              "user" : [ "attribute-badge-for-50th-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_100_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_100_viewed_question" : {
        "LABEL" : "Attribute badge for 100th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_100_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "23",
              "user" : [ "attribute-badge-for-100-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-100-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "21",
              "user" : [ "attribute-badge-for-100-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "22",
              "user" : [ "attribute-badge-for-100-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_250_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_250_viewed_question" : {
        "LABEL" : "Attribute badge for 250th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_250_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "24",
              "user" : [ "attribute-badge-for-250-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-250-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "21",
              "user" : [ "attribute-badge-for-250-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "22",
              "user" : [ "attribute-badge-for-250-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "23",
              "user" : [ "attribute-badge-for-250-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_500_viewed_question'] = entity_import('rules_config', '{ "rules_attribute_badge_for_500_viewed_question" : {
        "LABEL" : "Attribute badge for 500th viewed question",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_500_viewed_question_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "25",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "20",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "21",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "22",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "23",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "24",
              "user" : [ "attribute-badge-for-500-viewed-question-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_viewed_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_viewed_project" : {
        "LABEL" : "Attribute badge for 1st viewed project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_viewed_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "26",
              "user" : [ "attribute-badge-for-1st-viewed-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_viewed_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_viewed_project" : {
        "LABEL" : "Attribute badge for 5th viewed project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_viewed_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "27",
              "user" : [ "attribute-badge-for-5th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "26",
              "user" : [ "attribute-badge-for-5th-viewed-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_viewed_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_viewed_project" : {
        "LABEL" : "Attribute badge for 25th viewed project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_viewed_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "28",
              "user" : [ "attribute-badge-for-25th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "26",
              "user" : [ "attribute-badge-for-25th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "27",
              "user" : [ "attribute-badge-for-25th-viewed-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_viewed_project'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_viewed_project" : {
        "LABEL" : "Attribute badge for 50th viewed project",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_viewed_project_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "29",
              "user" : [ "attribute-badge-for-50th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "26",
              "user" : [ "attribute-badge-for-50th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "27",
              "user" : [ "attribute-badge-for-50th-viewed-project-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "28",
              "user" : [ "attribute-badge-for-50th-viewed-project-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_viewed_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_viewed_idea" : {
        "LABEL" : "Attribute badge for 1st viewed idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_viewed_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "30",
              "user" : [ "attribute-badge-for-1st-viewed-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_viewed_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_viewed_idea" : {
        "LABEL" : "Attribute badge for 5th viewed idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_viewed_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "31",
              "user" : [ "attribute-badge-for-5th-viewed-idea-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "30",
              "user" : [ "attribute-badge-for-5th-viewed-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_viewed_idea'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_viewed_idea" : {
        "LABEL" : "Attribute badge for 25th viewed idea",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_viewed_idea_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "32",
              "user" : [ "attribute-badge-for-25th-viewed-idea-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "30",
              "user" : [ "attribute-badge-for-25th-viewed-idea-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "31",
              "user" : [ "attribute-badge-for-25th-viewed-idea-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_1st_viewed_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_1st_viewed_article" : {
        "LABEL" : "Attribute badge for 1st viewed article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_1st_viewed_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "33",
              "user" : [ "attribute-badge-for-1st-viewed-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_5th_viewed_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_5th_viewed_article" : {
        "LABEL" : "Attribute badge for 5th viewed article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_5th_viewed_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "34",
              "user" : [ "attribute-badge-for-5th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "33",
              "user" : [ "attribute-badge-for-5th-viewed-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_25th_viewed_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_25th_viewed_article" : {
        "LABEL" : "Attribute badge for 25th viewed article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_25th_viewed_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "35",
              "user" : [ "attribute-badge-for-25th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "33",
              "user" : [ "attribute-badge-for-25th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "34",
              "user" : [ "attribute-badge-for-25th-viewed-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_for_50th_viewed_article'] = entity_import('rules_config', '{ "rules_attribute_badge_for_50th_viewed_article" : {
        "LABEL" : "Attribute badge for 50th viewed article",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_for_50th_viewed_article_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : {
              "badge" : "36",
              "user" : [ "attribute-badge-for-50th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "33",
              "user" : [ "attribute-badge-for-50th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "34",
              "user" : [ "attribute-badge-for-50th-viewed-article-user" ]
            }
          },
          { "remove_badge_by_name" : {
              "badge" : "35",
              "user" : [ "attribute-badge-for-50th-viewed-article-user" ]
            }
          }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_blogger'] = entity_import('rules_config', '{ "rules_attribute_badge_blogger" : {
        "LABEL" : "Attribute badge blogger",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges" ],
        "USES VARIABLES" : { "attribute_badge_blogger_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : { "badge" : "47", "user" : [ "attribute-badge-blogger-user" ] } }
        ]
      }
    }'
  );

  $components['rules_attribute_badge_guidelines'] = entity_import('rules_config', '{ "rules_attribute_badge_guidelines" : {
        "LABEL" : "Attribute badge guidelines \u0026 grant points",
        "PLUGIN" : "action set",
        "OWNER" : "rules",
        "TAGS" : [ "Gamification" ],
        "REQUIRES" : [ "user_badges", "userpoints_rules", "rules" ],
        "USES VARIABLES" : { "attribute_badge_guidelines_user" : { "label" : "User", "type" : "user" } },
        "ACTION SET" : [
          { "add_badge_by_name" : { "badge" : "46", "user" : [ "attribute-badge-guidelines-user" ] } },
          { "userpoints_action_grant_points" : {
              "user" : [ "attribute-badge-guidelines-user" ],
              "points" : "'. GAMIFICATION_GUIDELINES_POINTS .'",
              "tid" : "0",
              "entity" : [ "" ],
              "description" : "'. t('Reading of the Guidelines') .'",
              "operation" : "Read the Guidelines",
              "display" : 1,
              "moderate" : "approved"
            }
          },
          { "entity_create" : {
              "USING" : {
                "type" : "message",
                "param_type" : "activity_stream",
                "param_user" : [ "attribute-badge-guidelines-user" ]
              },
              "PROVIDE" : { "entity_created" : { "activity_stream" : "Activity Stream" } }
            }
          },
          { "data_set" : {
              "data" : [ "activity-stream:field-activity-stream-body:value" ],
              "value" : "You read the Guidelines"
            }
          },
          { "entity_save" : { "data" : [ "activity-stream" ], "immediate" : 1 } }
        ]
      }
    }'
  );

  return $components;
}

/**
 * Alter the default Voteup question rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_voteup_question_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / Message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['points'] = GAMIFICATION_VOTEUP_QUESTION_POINTS;
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Upvote of a question');
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You up voted the question <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default Votedown question rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_votedown_question_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Downvote of a question');

      switch ($action->settings['user:select']) {
        case 'node:author':
          $action->settings['points'] = GAMIFICATION_VOTEDOWN_QUESTION_POINTS;
          break;
        case 'vote:user':
          $action->settings['points'] = GAMIFICATION_VOTEDOWN_QUESTION_VOTER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You down voted the question <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default Voteup question cancel rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_voteup_question_cancel_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEUP_QUESTION_POINTS;
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Cancel upvote of a question');
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You canceled your up vote on the question <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default Voteup question cancel rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_votedown_question_cancel_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Cancel downvote of a question');

      switch ($action->settings['user:select']) {
        case 'node:author':
          $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEDOWN_QUESTION_POINTS;
          break;
        case 'vote:user':
          $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEDOWN_QUESTION_VOTER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You canceled your down vote on the question <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default Voteup answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_voteup_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['points'] = GAMIFICATION_VOTEUP_ANSWER_POINTS;
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Upvote of an answer');
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You up voted the answer <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default Votedown answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_votedown_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Downvote of an answer');

      switch ($action->settings['user:select']) {
        case 'node:author':
          $action->settings['points'] = GAMIFICATION_VOTEDOWN_ANSWER_POINTS;
          break;
        case 'vote:user':
          $action->settings['points'] = GAMIFICATION_VOTEDOWN_ANSWER_VOTER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You down voted the answer <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default voteup answer cancel rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_voteup_answer_cancel_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points / message
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEUP_ANSWER_POINTS;
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Cancel upvote of an answer');
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You canceled your up vote on the answer <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default votedown answer cancel rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_votedown_answer_cancel_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'node';
      $action->settings['operation'] = t('Cancel downvote of an answer');

      switch ($action->settings['user:select']) {
        case 'node:author':
          $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEDOWN_ANSWER_POINTS;
          break;
        case 'vote:user':
          $action->settings['points'] = (string) - (int) GAMIFICATION_VOTEDOWN_ANSWER_VOTER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You canceled your down vote on the answer <a href="[node:url]">[node:title]</a>.',
    'vote:user'
  );
}

/**
 * Alter the default flag best answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_flag_best_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'flagged-node';
      $action->settings['operation'] = t('Flag best answer');

      switch ($action->settings['user:select']) {
        case 'flagged-node:author':
          $action->settings['points'] = GAMIFICATION_RESOLVE_ANSWER_AUTHOR_POINTS;
          break;
        case 'flagging-user':
          $action->settings['points'] = GAMIFICATION_RESOLVE_ANSWER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You flagged <a href="[node:url]">[node:title]</a> as the best answer.',
    'flagging-user'
  );
}

/**
 * Alter the default unflag best answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_unflag_best_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'flagged-node';
      $action->settings['operation'] = t('Unflag best answer');

      switch ($action->settings['user:select']) {
        case 'flagged-node:author':
          $action->settings['points'] = (string) - (int) GAMIFICATION_RESOLVE_ANSWER_AUTHOR_POINTS;
          break;
        case 'flagging-user':
          $action->settings['points'] = (string) - (int) GAMIFICATION_RESOLVE_ANSWER_POINTS;
          break;
      }
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You unflagged <a href="[node:url]">[node:title]</a> as the best answer.',
    'flagging-user'
  );
}

/**
 * Alter the default flag best own answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_flag_best_own_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'flagged-node';
      $action->settings['operation'] = t('Flag best own answer');
      $action->settings['points'] = GAMIFICATION_RESOLVE_SELF_ANSWER_POINTS;
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You flagged <a href="[node:url]">[node:title]</a> as the best answer.',
    'flagging-user'
  );
}

/**
 * Alter the default unflag best own answer rule
 *
 * @param RulesReactionRule $rule
 */
function _group_mind_gamification_alter_unflag_best_own_answer_rule($rule) {
  // Change rule tag
  $rule->tags = array('gamification');

  // Change attributed points
  foreach ($rule->actions() as $action) {
    if ('userpoints_action_grant_points' == $action->getElementName()) {
      $action->settings['moderate'] = GAMIFICATION_MODERATION_APPROVED;
      $action->settings['entity:select'] = 'flagged-node';
      $action->settings['operation'] = t('Unflag best own answer');
      $action->settings['points'] = (string) - (int) GAMIFICATION_RESOLVE_SELF_ANSWER_POINTS;
    }
  }

  _group_mind_gamification_create_activity_stream_rule_action(
    $rule,
    'You unflagged <a href="[node:url]">[node:title]</a> as the best answer.',
    'flagging-user'
  );
}

/**
 * Create an Activity Stream entity rule action
 *
 * @param RulesReactionRule $rule The rule to add actions to
 * @param string		    $data The message to be written in the Activity stream
 * @param string            $user Target user
 */
function _group_mind_gamification_create_activity_stream_rule_action($rule, $data, $user) {
  // Create entity
  $rule->action(rules_action('entity_create', array(
    'type' 	     		   => 'message',
    'param_type' 		   => 'activity_stream',
    'param_user:select'    => $user,
    'entity_created:var'   => 'activity_stream',
    'entity_created:label' => 'Activity Stream',
  )));

  // Set entity data
  $rule->action(rules_action('data_set', array(
    'data:select' => 'activity-stream:field-activity-stream-body:value',
    'value'	      => t($data),
  )));

  // Save entity
  $rule->action(rules_action('entity_save', array(
    'data:select' => 'activity-stream',
    'immediate'	  => 1,
  )));
}

